@@ -10,7 +10,8 @@ from .core.kb_sync.object_time_interval import ObjectTimeInterval
 from .tdm_builder.tdm_builder import AbstractTdmBuilder
 from .providers.gql_providers import AbstractGQLClient
 from .schema.api_schema import Query, Mutation, StoryPagination, ConceptLinkPagination, ConceptFactPagination, \
-    ConceptPropertyPagination, SortDirection, ConceptSorting, DocumentSorting, DocumentGrouping, TimestampInterval
+    ConceptPropertyPagination, SortDirection, ConceptSorting, DocumentSorting, DocumentGrouping, TimestampInterval, \
+    PerformSynchronously
 from .schema.api_schema import \
     ValueInput, IntValueInput, StringValueInput, DateTimeValue, StringLocaleValue, StringValue, LinkValue, \
     DoubleValue, IntValue, ConceptPropertyFilterSettings, ConceptLinkFilterSettings, ExtraSettings, Story, Document,\
@@ -21,7 +22,8 @@ from .schema.api_schema import \
     ConceptPropertyValueTypeFilterSettings, ConceptPropertyValueTypeUpdateInput, ConceptProperty, \
     ConceptMutationInput, ConceptUpdateInput, ConceptPropertyUpdateInput, ConceptPropertyCreateInput, \
     ConceptLinkPropertyInput, ConceptLinkCreationMutationInput, ComponentValueInput, CompositeConcept, \
-    CompositeConceptWidgetRowPagination, DocumentLinkFilterSetting, ConceptFact
+    CompositeConceptWidgetRowPagination, DocumentLinkFilterSetting, ConceptFact, \
+    ConceptLinkPropertyTypeCreationInput, ConceptPropertyTypeCreationInput, State
 from .schema.crawlers_api_schema import Query as CrQuery
 from .schema.crawlers_api_schema import Crawler, CrawlerPagination
 from .schema import utils_api_schema as uas
@@ -45,13 +47,14 @@ class TalismanAPIAdapter:
     def __init__(
         self, gql_client: Optional[AbstractGQLClient], types: Dict, tdm_builder: AbstractTdmBuilder = None,
         utils_gql_client: Optional[AbstractGQLClient] = None, kb_iterator_config: KBIteratorConfig = None,
-        limit: int = 100
+        limit: int = 100, perform_synchronously: bool = True
     ) -> None:
         self._gql_client = gql_client
         self._utils_gql_client = utils_gql_client
         self._types = types
         self._cache = {}
         self._limit = limit
+        self._perform_synchronously = perform_synchronously
 
         self.document_fields_truncated = ('id', 'external_url')
         self.document_fields = (
@@ -112,9 +115,20 @@ class TalismanAPIAdapter:
     def limit(self, new_limit: int):
         self._limit = new_limit
 
+    @property
+    def perform_synchronously(self):
+        return self._perform_synchronously
+
+    @perform_synchronously.setter
+    def perform_synchronously(self, new_perform_synchronously: bool):
+        self._perform_synchronously = new_perform_synchronously
+
     def get_take_value(self, take: Optional[int]) -> int:
         return self.limit if take is None else take
 
+    def get_perform_synchronously_value(self, perform_synchronously: Optional[bool]) -> bool:
+        return self.perform_synchronously if perform_synchronously is None else perform_synchronously
+
     def _configure_property_value_type_fields(self, graphql_value, truncated: bool = True):
         conpvt_frag: Fragment = Fragment(ConceptPropertyValueType, 'ConceptPropertyValueType')
         for f in self.cpvt_fields_truncated if truncated else self.cpvt_fields:
@@ -220,14 +234,15 @@ class TalismanAPIAdapter:
             self._configure_output_value_fields(lcp.value)
 
     def _create_concept_with_input(
-        self, input: ConceptMutationInput, with_properties=False, with_links=False, with_link_properties=False
+        self, input: ConceptMutationInput, with_properties=False, with_links=False, with_link_properties=False,
+        perform_synchronously: Optional[bool] = None
     ) -> Concept:
-
+        perform_synchronously = self.get_perform_synchronously_value(perform_synchronously)
         op = Operation(Mutation)
         ac = op.add_concept(
-            # performance_control=PerformSynchronously(
-            #     perform_synchronously=False
-            # ),
+            performance_control=PerformSynchronously(
+                perform_synchronously=perform_synchronously
+            ),
             form=input
         )
         self._configure_output_concept_fields(
@@ -861,7 +876,7 @@ class TalismanAPIAdapter:
 
     def create_concept(
         self, name: str, type_id: str, notes: str = None, with_properties=False, with_links=False,
-        with_link_properties=False
+        with_link_properties=False, perform_synchronously: Optional[bool] = None
     ) -> Concept:
 
         cmi: ConceptMutationInput = ConceptMutationInput(
@@ -871,15 +886,18 @@ class TalismanAPIAdapter:
         )
         return self._create_concept_with_input(
             cmi, with_properties=with_properties, with_links=with_links,
-            with_link_properties=with_link_properties
+            with_link_properties=with_link_properties, perform_synchronously=perform_synchronously
         )
 
-    def update_concept(self, c: Concept, markers: List[str] = None, notes: str = None) -> Concept:
+    def update_concept(
+        self, c: Concept, markers: List[str] = None, notes: str = None, perform_synchronously: Optional[bool] = None
+    ) -> Concept:
+        perform_synchronously = self.get_perform_synchronously_value(perform_synchronously)
         op = Operation(Mutation)
         uc: Concept = op.update_concept(
-            # performance_control=PerformSynchronously(
-            #     perform_synchronously=False
-            # ),
+            performance_control=PerformSynchronously(
+                perform_synchronously=perform_synchronously
+            ),
             form=ConceptUpdateInput(
                 concept_id=c.id,
                 name=c.name,
@@ -914,9 +932,6 @@ class TalismanAPIAdapter:
     def update_concept_string_property(self, cp: ConceptProperty) -> ConceptProperty:
         op = Operation(Mutation)
         ucp: ConceptProperty = op.update_concept_property(
-            # performance_control=PerformSynchronously(
-            #     perform_synchronously=False
-            # ),
             form=ConceptPropertyUpdateInput(
                 property_id=cp.id,
                 is_main=cp.is_main,
@@ -1131,12 +1146,16 @@ class TalismanAPIAdapter:
                 return prop_type
         return None
 
-    def add_property_by_id(self, id: str, type_id: str, value: Any, is_main: bool, value_type: str) -> ConceptProperty:
+    def add_property_by_id(
+        self, id: str, type_id: str, value: Any, is_main: bool, value_type: str,
+        perform_synchronously: Optional[bool] = None
+    ) -> ConceptProperty:
+        perform_synchronously = self.get_perform_synchronously_value(perform_synchronously)
         op = Operation(Mutation)
         acp = op.add_concept_property(
-            # performance_control=PerformSynchronously(
-            #     perform_synchronously=False
-            # ),
+            performance_control=PerformSynchronously(
+                perform_synchronously=perform_synchronously
+            ),
             form=ConceptPropertyCreateInput(
                 concept_id=id,
                 property_type_id=type_id,
@@ -1156,14 +1175,16 @@ class TalismanAPIAdapter:
         return res.add_concept_property
 
     def add_property(
-        self, concept_id: str, concept_type_code: str, property_type_code: str, value: Any, is_main: bool = False
+        self, concept_id: str, concept_type_code: str, property_type_code: str, value: Any, is_main: bool = False,
+        perform_synchronously: Optional[bool] = None
     ) -> ConceptProperty:
 
         property_type: ConceptPropertyType = self.get_concept_property_type(concept_type_code, property_type_code)
         if not property_type:
             raise Exception('Cannot add property: no property type id')
         prop = self.add_property_by_id(
-            concept_id, property_type.id, value, is_main, property_type.value_type.value_type
+            concept_id, property_type.id, value, is_main, property_type.value_type.value_type,
+            perform_synchronously=perform_synchronously
         )
 
         if self.tdm_builder is not None:
@@ -1172,15 +1193,16 @@ class TalismanAPIAdapter:
         return prop
 
     def add_link_property_by_id(
-        self, link_id: str, type_id: str, value: str, is_main: bool, value_type: str
+        self, link_id: str, type_id: str, value: str, is_main: bool, value_type: str,
+        perform_synchronously: Optional[bool] = None
     ) -> ConceptProperty:
-
+        perform_synchronously = self.get_perform_synchronously_value(perform_synchronously)
         op = Operation(Mutation)
 
         aclp = op.add_concept_link_property(
-            # performance_control=PerformSynchronously(
-            #     perform_synchronously=False
-            # ),
+            performance_control=PerformSynchronously(
+                perform_synchronously=perform_synchronously
+            ),
             form=ConceptLinkPropertyInput(
                 property_type_id=type_id,
                 link_id=link_id,
@@ -1199,9 +1221,75 @@ class TalismanAPIAdapter:
 
         return res.add_concept_link_property
 
+    def add_concept_link_property_type(
+        self, link_type_id: str, name: str, value_type_id: str
+    ) -> ConceptPropertyType:
+
+        op = Operation(Mutation)
+
+        aclpt = op.add_concept_link_property_type(
+            form=ConceptLinkPropertyTypeCreationInput(
+                link_type_id = link_type_id,
+                name=name,
+                value_type_id=value_type_id,
+            )
+        )
+        aclpt.__fields__(*self.concept_property_type_fields)
+        res = self._gql_client.execute(op)
+        res = op + res
+
+        return res.add_concept_link_property_type
+
+    def delete_concept_link_property_type(
+        self, property_type_id: str
+    ) -> State:
+
+        op = Operation(Mutation)
+
+        op.delete_concept_link_property_type(
+            id=property_type_id
+        )
+        res = self._gql_client.execute(op)
+        res = op + res
+
+        return res.delete_concept_link_property_type
+
+    def add_concept_property_type(
+        self, concept_type_id: str, name: str, value_type_id: str
+    ) -> ConceptPropertyType:
+
+        op = Operation(Mutation)
+
+        acpt = op.add_concept_property_type(
+            form=ConceptPropertyTypeCreationInput(
+                concept_type_id = concept_type_id,
+                name=name,
+                value_type_id=value_type_id,
+            )
+        )
+        acpt.__fields__(*self.concept_property_type_fields)
+        res = self._gql_client.execute(op)
+        res = op + res
+
+        return res.add_concept_property_type
+
+    def delete_concept_property_type(
+        self, property_type_id: str
+    ) -> State:
+
+        op = Operation(Mutation)
+
+        op.delete_concept_property_type(
+            id=property_type_id
+        )
+        res = self._gql_client.execute(op)
+        res = op + res
+
+        return res.delete_concept_property_type
+
     def add_link_property(
         self, link_id: str, link_type_code: str, link_type: ConceptLinkType, property_type_code: str, value: Any,
-        is_main: bool = False
+        is_main: bool = False, perform_synchronously: Optional[bool] = None
     ) -> ConceptProperty:
 
         property_type: ConceptPropertyType = self.get_link_property_type(link_type_code, link_type, property_type_code)
@@ -1209,16 +1297,13 @@ class TalismanAPIAdapter:
             raise Exception('Cannot add property: no property type id')
         link_property = self.add_link_property_by_id(
             link_id, property_type.id, value, is_main,
-            property_type.value_type.value_type
+            property_type.value_type.value_type, perform_synchronously=perform_synchronously
         )
 
         if self.tdm_builder is not None:
             self.tdm_builder.add_link_property_fact(link_property, self.get_concept_link(link_id), value, property_type)
 
-        return self.add_link_property_by_id(
-            link_id, property_type.id, value, is_main,
-            property_type.value_type.value_type
-        )
+        return link_property
 
     def get_concept_link_type_by_name(
         self, link_name: str, from_type_id: str, to_type_id: str
@@ -1261,12 +1346,15 @@ class TalismanAPIAdapter:
                 return link_type
         return None
 
-    def add_relation_by_id(self, from_id: str, to_id: str, link_type_id: str) -> ConceptLink:
+    def add_relation_by_id(
+        self, from_id: str, to_id: str, link_type_id: str, perform_synchronously: Optional[bool] = None
+    ) -> ConceptLink:
+        perform_synchronously = self.get_perform_synchronously_value(perform_synchronously)
         op = Operation(Mutation)
         acl = op.add_concept_link(
-            # performance_control=PerformSynchronously(
-            #     perform_synchronously=False
-            # ),
+            performance_control=PerformSynchronously(
+                perform_synchronously=perform_synchronously
+            ),
             form=ConceptLinkCreationMutationInput(
                 concept_from_id=from_id,
                 concept_to_id=to_id,
@@ -1286,13 +1374,15 @@ class TalismanAPIAdapter:
 
     def add_relation(
         self, concept_from_id: str, concept_to_id: str, concept_from_type_code: str, concept_to_type_code: str,
-        type_code: str
+        type_code: str, perform_synchronously: Optional[bool] = None
     ) -> ConceptLink:
 
         link_type = self.get_link_type(concept_from_type_code, concept_to_type_code, type_code)
         if not link_type:
             raise Exception('Cannot add relation: no link type')
-        relation = self.add_relation_by_id(concept_from_id, concept_to_id, link_type.id)
+        relation = self.add_relation_by_id(
+            concept_from_id, concept_to_id, link_type.id, perform_synchronously=perform_synchronously
+        )
 
         if self.tdm_builder is not None:
             self.tdm_builder.add_link_fact(relation)
@@ -1335,15 +1425,19 @@ class TalismanAPIAdapter:
 
         return res.delete_concept_link_property.is_success
 
-    def add_concept_markers(self, concept_id: str, markers: List[str]) -> Concept:
+    def add_concept_markers(
+        self, concept_id: str, markers: List[str], perform_synchronously: Optional[bool] = None
+    ) -> Concept:
         c = self.get_concept(concept_id)
         c.markers.extend(markers)
         new_markers = list(set(c.markers))
-        return self.update_concept(c, markers=new_markers)
+        return self.update_concept(c, markers=new_markers, perform_synchronously=perform_synchronously)
 
-    def set_concept_markers(self, concept_id: str, markers: List[str]) -> Concept:
+    def set_concept_markers(
+        self, concept_id: str, markers: List[str], perform_synchronously: Optional[bool] = None
+    ) -> Concept:
         c = self.get_concept(concept_id)
-        return self.update_concept(c, markers=markers)
+        return self.update_concept(c, markers=markers, perform_synchronously=perform_synchronously)
 
     def get_composite_concept(self, root_concept_id: str, composite_concept_type_id: str) -> CompositeConcept:
         op = Operation(Query)
