@@ -15,6 +15,11 @@ class CollectionStatus(sgqlc.types.Enum):
     __choices__ = ('Canceled', 'Error', 'InProgress', 'Success', 'WithMistakes')
 
 
+class CrawlStateSorting(sgqlc.types.Enum):
+    __schema__ = crawlers_api_schema
+    __choices__ = ('crawlKey', 'creatorId', 'id', 'lastUpdaterId', 'systemRegistrationDate', 'systemUpdateDate')
+
+
 class CrawlerSorting(sgqlc.types.Enum):
     __schema__ = crawlers_api_schema
     __choices__ = ('avgPerformanceTime', 'id', 'lastCollectionDate', 'projectTitle', 'title')
@@ -168,6 +173,38 @@ class VersionStatus(sgqlc.types.Enum):
 ########################################################################
 # Input Objects
 ########################################################################
+class AddCrawlStateInput(sgqlc.types.Input):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('state', 'cookie', 'parameters')
+    state = sgqlc.types.Field(sgqlc.types.non_null(JSON), graphql_name='state')
+    cookie = sgqlc.types.Field(JSON, graphql_name='cookie')
+    parameters = sgqlc.types.Field(sgqlc.types.non_null('CrawlStateParameters'), graphql_name='parameters')
+
+
+class CrawlStateFilterSettings(sgqlc.types.Input):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('input_value', 'crawler_ids', 'periodic_job_ids', 'credential_ids', 'information_source_ids', 'creator_ids', 'last_updater_ids', 'system_registration_date', 'system_update_date')
+    input_value = sgqlc.types.Field(String, graphql_name='inputValue')
+    crawler_ids = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='crawlerIds')
+    periodic_job_ids = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='periodicJobIds')
+    credential_ids = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='credentialIds')
+    information_source_ids = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='informationSourceIds')
+    creator_ids = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='creatorIds')
+    last_updater_ids = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(String)), graphql_name='lastUpdaterIds')
+    system_registration_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemRegistrationDate')
+    system_update_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemUpdateDate')
+
+
+class CrawlStateParameters(sgqlc.types.Input):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('crawler_id', 'periodic_job_id', 'credential_id', 'information_source_id', 'crawl_key')
+    crawler_id = sgqlc.types.Field(ID, graphql_name='crawlerId')
+    periodic_job_id = sgqlc.types.Field(ID, graphql_name='periodicJobId')
+    credential_id = sgqlc.types.Field(ID, graphql_name='credentialId')
+    information_source_id = sgqlc.types.Field(ID, graphql_name='informationSourceId')
+    crawl_key = sgqlc.types.Field(String, graphql_name='crawlKey')
+
+
 class CrawlerFilterSettings(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
     __field_names__ = ('input_value', 'projects', 'crawlers_types', 'last_collection_date', 'created_by', 'changed_by', 'created_at', 'changed_at', 'have_active_versions')
@@ -184,14 +221,12 @@ class CrawlerFilterSettings(sgqlc.types.Input):
 
 class CrawlerUpdateInput(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('project_id', 'title', 'description', 'settings', 'args', 'state', 'state_version')
+    __field_names__ = ('project_id', 'title', 'description', 'settings', 'args')
     project_id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='projectId')
     title = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='title')
     description = sgqlc.types.Field(String, graphql_name='description')
     settings = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('KeyValueInputType'))), graphql_name='settings')
     args = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('KeyValueInputType'))), graphql_name='args')
-    state = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null('KeyValueInputType'))), graphql_name='state')
-    state_version = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='stateVersion')
 
 
 class CredentialFilterSettings(sgqlc.types.Input):
@@ -209,7 +244,7 @@ class CredentialFilterSettings(sgqlc.types.Input):
 
 class CredentialInput(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('projects', 'status', 'domain', 'description', 'data_type', 'login', 'password', 'token', 'state', 'cookies')
+    __field_names__ = ('projects', 'status', 'domain', 'description', 'data_type', 'login', 'password', 'token')
     projects = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(ID))), graphql_name='projects')
     status = sgqlc.types.Field(CredentialStatus, graphql_name='status')
     domain = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='domain')
@@ -218,8 +253,6 @@ class CredentialInput(sgqlc.types.Input):
     login = sgqlc.types.Field(String, graphql_name='login')
     password = sgqlc.types.Field(String, graphql_name='password')
     token = sgqlc.types.Field(String, graphql_name='token')
-    state = sgqlc.types.Field(JSON, graphql_name='state')
-    cookies = sgqlc.types.Field(JSON, graphql_name='cookies')
 
 
 class FileSettings(sgqlc.types.Input):
@@ -414,6 +447,15 @@ class TimestampInterval(sgqlc.types.Input):
     end = sgqlc.types.Field(UnixTime, graphql_name='end')
 
 
+class UpdateCrawlStateInput(sgqlc.types.Input):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('state', 'cookie', 'state_version', 'credential_status')
+    state = sgqlc.types.Field(sgqlc.types.non_null(JSON), graphql_name='state')
+    cookie = sgqlc.types.Field(JSON, graphql_name='cookie')
+    state_version = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='stateVersion')
+    credential_status = sgqlc.types.Field(CredentialStatus, graphql_name='credentialStatus')
+
+
 class VersionFilterSettings(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
     __field_names__ = ('input_value', 'with_removed_versions')
@@ -432,6 +474,24 @@ class ArgsAndSettingsDescription(sgqlc.types.Type):
     settings = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null('SettingDescription')), graphql_name='settings')
 
 
+class CrawlState(sgqlc.types.Type):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('id', 'crawler_id', 'periodic_job_id', 'credential_id', 'information_source_id', 'crawl_key', 'state', 'cookie', 'state_version', 'creator', 'system_registration_date', 'last_updater', 'system_update_date')
+    id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='id')
+    crawler_id = sgqlc.types.Field(ID, graphql_name='crawlerId')
+    periodic_job_id = sgqlc.types.Field(ID, graphql_name='periodicJobId')
+    credential_id = sgqlc.types.Field(ID, graphql_name='credentialId')
+    information_source_id = sgqlc.types.Field(ID, graphql_name='informationSourceId')
+    crawl_key = sgqlc.types.Field(String, graphql_name='crawlKey')
+    state = sgqlc.types.Field(sgqlc.types.non_null(JSON), graphql_name='state')
+    cookie = sgqlc.types.Field(JSON, graphql_name='cookie')
+    state_version = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='stateVersion')
+    creator = sgqlc.types.Field(sgqlc.types.non_null('User'), graphql_name='creator')
+    system_registration_date = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='systemRegistrationDate')
+    last_updater = sgqlc.types.Field('User', graphql_name='lastUpdater')
+    system_update_date = sgqlc.types.Field(UnixTime, graphql_name='systemUpdateDate')
+
+
 class CrawlerData(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
     __field_names__ = ('id', 'title', 'name')
@@ -460,11 +520,11 @@ class CrawlerStats(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
     __field_names__ = ('items_scraped_count', 'next_schedule_time', 'total_time', 'items_scraped_count_last', 'avg_performance_time', 'last_collection_date')
     items_scraped_count = sgqlc.types.Field(Long, graphql_name='itemsScrapedCount')
-    next_schedule_time = sgqlc.types.Field(Long, graphql_name='nextScheduleTime')
+    next_schedule_time = sgqlc.types.Field(UnixTime, graphql_name='nextScheduleTime')
     total_time = sgqlc.types.Field(Long, graphql_name='totalTime')
     items_scraped_count_last = sgqlc.types.Field(Long, graphql_name='itemsScrapedCountLast')
     avg_performance_time = sgqlc.types.Field(Long, graphql_name='avgPerformanceTime')
-    last_collection_date = sgqlc.types.Field(Long, graphql_name='lastCollectionDate')
+    last_collection_date = sgqlc.types.Field(UnixTime, graphql_name='lastCollectionDate')
 
 
 class CredentialPagination(sgqlc.types.Type):
@@ -598,19 +658,17 @@ class Metric(sgqlc.types.Type):
 
 class Mutation(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('update_crawler', 'update_crawler_settings_arguments_and_state', 'delete_crawler_versions', 'delete_crawlers', 'update_site_map_crawler_body', 'add_credential', 'update_credential', 'delete_credential', 'single_upload', 'add_job', 'delete_job', 'cancel_job', 'add_periodic_job', 'run_periodic_jobs', 'update_enable_jobs_scheduling', 'update_disable_jobs_scheduling', 'delete_periodic_job', 'update_periodic_job', 'update_periodic_job_settings_and_arguments', 'delete_project', 'delete_project_versions', 'add_project', 'update_project', 'update_set_active_project', 'update_remove_active_project', 'update_project_settings_and_arguments', 'add_information_source_loader', 'delete_information_source_loader')
+    __field_names__ = ('update_crawler', 'update_crawler_settings_arguments', 'delete_crawler_versions', 'delete_crawlers', 'update_site_map_crawler_body', 'add_crawl_state', 'update_crawl_state', 'delete_crawl_state', 'add_credential', 'update_credential', 'delete_credential', 'single_upload', 'add_job', 'delete_job', 'cancel_job', 'add_periodic_job', 'run_periodic_jobs', 'update_enable_jobs_scheduling', 'update_disable_jobs_scheduling', 'delete_periodic_job', 'update_periodic_job', 'update_periodic_job_settings_and_arguments', 'delete_project', 'delete_project_versions', 'add_project', 'update_project', 'update_set_active_project', 'update_remove_active_project', 'update_project_settings_and_arguments', 'add_information_source_loader', 'delete_information_source_loader')
     update_crawler = sgqlc.types.Field(sgqlc.types.non_null('Crawler'), graphql_name='updateCrawler', args=sgqlc.types.ArgDict((
         ('crawler_update_input', sgqlc.types.Arg(sgqlc.types.non_null(CrawlerUpdateInput), graphql_name='crawlerUpdateInput', default=None)),
         ('crawler_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='crawlerId', default=None)),
         ('project_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='projectId', default=None)),
 ))
     )
-    update_crawler_settings_arguments_and_state = sgqlc.types.Field(sgqlc.types.non_null('Crawler'), graphql_name='updateCrawlerSettingsArgumentsAndState', args=sgqlc.types.ArgDict((
+    update_crawler_settings_arguments = sgqlc.types.Field(sgqlc.types.non_null('Crawler'), graphql_name='updateCrawlerSettingsArguments', args=sgqlc.types.ArgDict((
         ('crawler_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='crawlerId', default=None)),
         ('settings', sgqlc.types.Arg(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValueInputType))), graphql_name='settings', default=None)),
         ('args', sgqlc.types.Arg(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValueInputType))), graphql_name='args', default=None)),
-        ('state', sgqlc.types.Arg(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValueInputType))), graphql_name='state', default=None)),
-        ('state_version', sgqlc.types.Arg(sgqlc.types.non_null(Long), graphql_name='stateVersion', default=None)),
 ))
     )
     delete_crawler_versions = sgqlc.types.Field(sgqlc.types.non_null('State'), graphql_name='deleteCrawlerVersions', args=sgqlc.types.ArgDict((
@@ -626,6 +684,19 @@ class Mutation(sgqlc.types.Type):
         ('crawler_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='crawlerId', default=None)),
         ('project_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='projectId', default=None)),
         ('json', sgqlc.types.Arg(sgqlc.types.non_null(JSON), graphql_name='json', default=None)),
+))
+    )
+    add_crawl_state = sgqlc.types.Field(sgqlc.types.non_null(CrawlState), graphql_name='addCrawlState', args=sgqlc.types.ArgDict((
+        ('add_crawl_state_input', sgqlc.types.Arg(sgqlc.types.non_null(AddCrawlStateInput), graphql_name='addCrawlStateInput', default=None)),
+))
+    )
+    update_crawl_state = sgqlc.types.Field(sgqlc.types.non_null(CrawlState), graphql_name='updateCrawlState', args=sgqlc.types.ArgDict((
+        ('crawl_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='crawlId', default=None)),
+        ('update_crawl_state_input', sgqlc.types.Arg(sgqlc.types.non_null(UpdateCrawlStateInput), graphql_name='updateCrawlStateInput', default=None)),
+))
+    )
+    delete_crawl_state = sgqlc.types.Field(sgqlc.types.non_null('State'), graphql_name='deleteCrawlState', args=sgqlc.types.ArgDict((
+        ('crawl_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='crawlId', default=None)),
 ))
     )
     add_credential = sgqlc.types.Field(sgqlc.types.non_null('Credential'), graphql_name='addCredential', args=sgqlc.types.ArgDict((
@@ -731,6 +802,13 @@ class Mutation(sgqlc.types.Type):
     )
 
 
+class PaginationCrawlState(sgqlc.types.Type):
+    __schema__ = crawlers_api_schema
+    __field_names__ = ('total', 'list_crawl_state')
+    total = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='total')
+    list_crawl_state = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(CrawlState))), graphql_name='listCrawlState')
+
+
 class PaginationInformationSource(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
     __field_names__ = ('total', 'list_information_source')
@@ -822,7 +900,7 @@ class ProjectStats(sgqlc.types.Type):
 
 class Query(sgqlc.types.Type):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('analytics', 'crawler', 'list_crawler', 'pagination_crawler', 'crawler_args_and_settings_description', 'credential', 'pagination_credential', 'job', 'list_job', 'pagination_job_logs', 'pagination_job_requests', 'pagination_job_metrics', 'pagination_job', 'periodic_job', 'pagination_periodic_job', 'pagination_periodic_job_logs', 'pagination_periodic_job_requests', 'pagination_periodic_job_metrics', 'check_periodic_job_by_input', 'project', 'pagination_project', 'project_args_and_settings_description', 'project_default_args_and_settings_description', 'information_source_loader', 'pagination_information_source_loader', 'information_source', 'pagination_information_source', 'version', 'list_version', 'pagination_versions_crawler', 'pagination_egg_file_versions_project', 'web_scraper_version_is_compatible')
+    __field_names__ = ('analytics', 'crawler', 'list_crawler', 'pagination_crawler', 'crawler_args_and_settings_description', 'crawl_state', 'crawl_state_by_parameters', 'pagination_crawl_state', 'credential', 'pagination_credential', 'job', 'list_job', 'pagination_job_logs', 'pagination_job_requests', 'pagination_job_metrics', 'pagination_job', 'periodic_job', 'pagination_periodic_job', 'pagination_periodic_job_logs', 'pagination_periodic_job_requests', 'pagination_periodic_job_metrics', 'check_periodic_job_by_input', 'project', 'pagination_project', 'project_args_and_settings_description', 'project_default_args_and_settings_description', 'information_source_loader', 'pagination_information_source_loader', 'information_source', 'pagination_information_source', 'version', 'list_version', 'pagination_versions_crawler', 'pagination_egg_file_versions_project', 'web_scraper_version_is_compatible')
     analytics = sgqlc.types.Field(sgqlc.types.non_null('Stats'), graphql_name='analytics')
     crawler = sgqlc.types.Field(sgqlc.types.non_null('Crawler'), graphql_name='crawler', args=sgqlc.types.ArgDict((
         ('id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='id', default=None)),
@@ -843,6 +921,22 @@ class Query(sgqlc.types.Type):
     crawler_args_and_settings_description = sgqlc.types.Field(sgqlc.types.non_null(ArgsAndSettingsDescription), graphql_name='crawlerArgsAndSettingsDescription', args=sgqlc.types.ArgDict((
         ('crawler_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='crawlerId', default=None)),
         ('version_id', sgqlc.types.Arg(ID, graphql_name='versionId', default=None)),
+))
+    )
+    crawl_state = sgqlc.types.Field(sgqlc.types.non_null(CrawlState), graphql_name='crawlState', args=sgqlc.types.ArgDict((
+        ('crawl_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='crawlId', default=None)),
+))
+    )
+    crawl_state_by_parameters = sgqlc.types.Field(sgqlc.types.non_null(CrawlState), graphql_name='crawlStateByParameters', args=sgqlc.types.ArgDict((
+        ('crawl_state_parameters', sgqlc.types.Arg(sgqlc.types.non_null(CrawlStateParameters), graphql_name='crawlStateParameters', default=None)),
+))
+    )
+    pagination_crawl_state = sgqlc.types.Field(sgqlc.types.non_null(PaginationCrawlState), graphql_name='paginationCrawlState', args=sgqlc.types.ArgDict((
+        ('limit', sgqlc.types.Arg(Int, graphql_name='limit', default=20)),
+        ('offset', sgqlc.types.Arg(Int, graphql_name='offset', default=0)),
+        ('filter_settings', sgqlc.types.Arg(CrawlStateFilterSettings, graphql_name='filterSettings', default={})),
+        ('sort_field', sgqlc.types.Arg(CrawlStateSorting, graphql_name='sortField', default='id')),
+        ('direction', sgqlc.types.Arg(SortDirection, graphql_name='direction', default='descending')),
 ))
     )
     credential = sgqlc.types.Field(sgqlc.types.non_null('Credential'), graphql_name='credential', args=sgqlc.types.ArgDict((
@@ -1115,7 +1209,7 @@ class VersionPagination(sgqlc.types.Type):
 
 class Crawler(sgqlc.types.Type, RecordInterface):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('id', 'name', 'title', 'description', 'project', 'periodic_jobs_num', 'onetime_jobs_num', 'last_collection_date', 'state_version', 'avg_performance_time', 'pinned', 'settings', 'args', 'state', 'analytics', 'histogram_items', 'histogram_requests', 'job_stats', 'current_version', 'start_urls', 'sitemap')
+    __field_names__ = ('id', 'name', 'title', 'description', 'project', 'periodic_jobs_num', 'onetime_jobs_num', 'last_collection_date', 'avg_performance_time', 'pinned', 'settings', 'args', 'analytics', 'histogram_items', 'histogram_requests', 'job_stats', 'current_version', 'start_urls', 'sitemap')
     id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='id')
     name = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='name')
     title = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='title')
@@ -1123,13 +1217,11 @@ class Crawler(sgqlc.types.Type, RecordInterface):
     project = sgqlc.types.Field(sgqlc.types.non_null(ProjectData), graphql_name='project')
     periodic_jobs_num = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='periodicJobsNum')
     onetime_jobs_num = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='onetimeJobsNum')
-    last_collection_date = sgqlc.types.Field(Long, graphql_name='lastCollectionDate')
-    state_version = sgqlc.types.Field(sgqlc.types.non_null(Long), graphql_name='stateVersion')
+    last_collection_date = sgqlc.types.Field(UnixTime, graphql_name='lastCollectionDate')
     avg_performance_time = sgqlc.types.Field(Float, graphql_name='avgPerformanceTime')
     pinned = sgqlc.types.Field(sgqlc.types.non_null(Boolean), graphql_name='pinned')
     settings = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValue))), graphql_name='settings')
     args = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValue))), graphql_name='args')
-    state = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValue))), graphql_name='state')
     analytics = sgqlc.types.Field(sgqlc.types.non_null(CrawlerStats), graphql_name='analytics', args=sgqlc.types.ArgDict((
         ('interval', sgqlc.types.Arg(TimestampInterval, graphql_name='interval', default=None)),
 ))
@@ -1153,7 +1245,7 @@ class Crawler(sgqlc.types.Type, RecordInterface):
 
 class Credential(sgqlc.types.Type, RecordInterface):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('id', 'data_type', 'description', 'login', 'password', 'token', 'domain', 'projects', 'status', 'state', 'cookies', 'version')
+    __field_names__ = ('id', 'data_type', 'description', 'login', 'password', 'token', 'domain', 'projects', 'status')
     id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='id')
     data_type = sgqlc.types.Field(sgqlc.types.non_null(CredentialType), graphql_name='dataType')
     description = sgqlc.types.Field(String, graphql_name='description')
@@ -1163,9 +1255,6 @@ class Credential(sgqlc.types.Type, RecordInterface):
     domain = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='domain')
     projects = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(ProjectData))), graphql_name='projects')
     status = sgqlc.types.Field(sgqlc.types.non_null(CredentialStatus), graphql_name='status')
-    state = sgqlc.types.Field(JSON, graphql_name='state')
-    cookies = sgqlc.types.Field(JSON, graphql_name='cookies')
-    version = sgqlc.types.Field(sgqlc.types.non_null(Int), graphql_name='version')
 
 
 class InformationSourceLoader(sgqlc.types.Type, RecordInterface):
@@ -1189,8 +1278,8 @@ class Job(sgqlc.types.Type, RecordInterface):
     id = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='id')
     status = sgqlc.types.Field(sgqlc.types.non_null(JobStatus), graphql_name='status')
     priority = sgqlc.types.Field(sgqlc.types.non_null(JobPriorityType), graphql_name='priority')
-    start_time = sgqlc.types.Field(Long, graphql_name='startTime')
-    end_time = sgqlc.types.Field(Long, graphql_name='endTime')
+    start_time = sgqlc.types.Field(UnixTime, graphql_name='startTime')
+    end_time = sgqlc.types.Field(UnixTime, graphql_name='endTime')
     collection_status = sgqlc.types.Field(sgqlc.types.non_null(CollectionStatus), graphql_name='collectionStatus')
     is_noise = sgqlc.types.Field(sgqlc.types.non_null(Boolean), graphql_name='isNoise')
     crawler = sgqlc.types.Field(sgqlc.types.non_null(CrawlerData), graphql_name='crawler')
@@ -1219,7 +1308,7 @@ class PeriodicJob(sgqlc.types.Type, RecordInterface):
     status = sgqlc.types.Field(sgqlc.types.non_null(PeriodicJobStatus), graphql_name='status')
     cron = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='cron')
     cron_utcoffset_minutes = sgqlc.types.Field(sgqlc.types.non_null(Int), graphql_name='cronUTCOffsetMinutes')
-    next_schedule_time = sgqlc.types.Field(Long, graphql_name='nextScheduleTime')
+    next_schedule_time = sgqlc.types.Field(UnixTime, graphql_name='nextScheduleTime')
     update_on_reload = sgqlc.types.Field(sgqlc.types.non_null(Boolean), graphql_name='updateOnReload')
     settings = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValue))), graphql_name='settings')
     args = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(KeyValue))), graphql_name='args')
